@@ -335,20 +335,6 @@ class GenericFieldSet(BasicFieldSet):
             self._stopFeeding()
         return None
 
-    def readFirstFields(self, number):
-        """
-        Read first number fields if they are not read yet.
-
-        Returns number of new added fields.
-        """
-        if self._field_generator is None:
-            return
-        number = number - len(self._fields)
-        if 0 < number:
-            return self.readMoreFields(number)
-        else:
-            return 0
-
     def readMoreFields(self, number):
         """
         Read more number fields, or do nothing if parsing is done.
@@ -482,7 +468,7 @@ class GenericFieldSet(BasicFieldSet):
                         "Unable to replace %s: name \"%s\" is already used!"
                         % (name, field.name))
                 self._fields.insert(index, field.name, field)
-                self.raiseEvent("field-insered", index, field)
+                self.raiseEvent("field-inserted", index, field)
                 index += 1
                 address += field.size
 
